import MediaError from "video.js/dist/types/media-error";
/** Player function imports */
import Volume from "./volume";
import UI from "./ui";
/** Player type imports */
import { PlayerOptions } from "../types";
/** MediaError for when there are provider disconnections or unavailable service */
export declare const BWP_PLAYER_OFFLINE_ERROR: MediaError;
export declare const BWP_PLAYER_DEFAULT_ERROR: MediaError;
/** Default Web Player options in case some of the options have not been passed */
export declare const defaultBayesWebPlayerOptions: PlayerOptions;
declare class Player {
    /** Player variables */
    private bwpUri;
    private bwpContainer;
    private bwpOptions;
    private bwpPlayer;
    private bwpId;
    private bwpDocument;
    /** Error Modal */
    private bwpModal;
    /** Timers */
    private bwpErrorTimeout;
    private bwpTimeUpdateTimeout;
    /** Exposed APIs */
    volume: Volume;
    ui: UI;
    /**
     * @param uri Playlist URL to be loaded in to the embeddable player.
     * @param container Container ID where the player needs to be embedded.
     * @param options Bayes Web Player options.
     */
    constructor(uri: string, container: string | HTMLDivElement, options?: PlayerOptions, doc?: Document);
    /**
     * Returns the HTMLElement for a given id.
     * @returns {HTMLElement} HTML Element for provided id.
     * TODO: Error handing for when the provided element is missing.
     */
    private bwpGetParentContainer;
    /**
     * Creates the video tag that would be used for the player instance.
     */
    private bwpCreateVideoElement;
    /**
     * Function to be invoked when the player is initialised. Important since some options
     * cannot be configured when initializing but only when the player is ready.
     */
    private bwpOnPlayerReady;
    /**
     * The function copies the computed styles from the original
     * document in case of iframe implementations since video.js
     * by defaults
     */
    private bwpCopyOriginalStylesheets;
    private bwpOnPlayerPlay;
    private bwpOnPlayerError;
    private bwpOnPlayerPause;
    private bwpOnPlayerRetry;
    private bwpOnPlayerEnded;
    private bwpOnPlayerRetryPlaylist;
    private bwpOnPlayerInterrupt;
    private bwpOnPlayerClearError;
    private bwpOnPlayerTimeElapsed;
    /**
     * Initialize the Bayes Web Player instance
     */
    init(): void;
    /**
     * Play the current stream that is active in the Bayes
     * Web Player.
     */
    play(): Promise<void>;
    /**
     * Pause the current stream that is being played in the
     * Bayes Web Player.
     */
    pause(): void;
    /**
     * Removes the Bayes Web Player
     */
    destroy(): boolean;
    metadata(): {
        bufferLength: number;
        currentTime: any;
        duration: any;
        bandwidth: any;
        timestamp: any;
        playerDimensions: any;
        mediaInfo: {
            mediaSequence: any;
            mediaSecondsLoaded: any;
            mediaRequests: any;
            mediaRequestsAborted: any;
            mediaRequestsErrored: any;
            mediaRequestsTimedout: any;
            mediaBytesTransferred: any;
        };
        videoPlaybackQuality: {
            totalVideoFrames: any;
            corruptedVideoFrames: any;
            droppedVideoFrames: any;
            framesPerSecond: number;
        };
    } | {
        bufferLength?: undefined;
        currentTime?: undefined;
        duration?: undefined;
        bandwidth?: undefined;
        timestamp?: undefined;
        playerDimensions?: undefined;
        mediaInfo?: undefined;
        videoPlaybackQuality?: undefined;
    };
}
export default Player;
