import MediaError from "video.js/dist/types/media-error";
import VideoJsPlayer from "video.js/dist/types/player";
/** Video JS Extended Player */
export type ExtendedPlayer = VideoJsPlayer & {
    [key: string]: any;
    tech: any;
};
/** Global typings */
export type StringKeyValuePair = {
    [key: string]: string;
};
/** Enumeration type for number range */
export type Enumerate<N extends number, Acc extends number[] = []> = Acc["length"] extends N ? Acc[number] : Enumerate<N, [...Acc, Acc["length"]]>;
/** Create a type with a value between a given range of numbers. */
export type IntRange<F extends number, T extends number> = Exclude<Enumerate<T>, Enumerate<F>>;
/** Styling types */
export declare const StyleProps: {
    color: string;
    colorHover: string;
    backgroundColor: string;
};
export declare const StyleKeys: {
    controls: string;
    playButton: string;
    controlBar: string;
};
export type KeyOfStyleKeys = keyof typeof StyleKeys;
export type ValueOfStyleKeys = keyof typeof StyleProps;
export type StyleParams = {
    [key in keyof typeof StyleProps]?: string;
};
export type StyleOptions = {
    [key in keyof typeof StyleKeys]?: StyleParams;
};
/** Watermarking types */
export type WatermarkPosition = "top-left" | "top-right" | "bottom-left" | "bottom-right";
export type WatermarkSize = "sm" | "md" | "lg";
export type WatermarkOptions = {
    src: string;
    position?: WatermarkPosition;
    size?: WatermarkSize;
    opacity?: number;
    onClick?: () => void;
};
/** Player types */
export type PlayerOptions = {
    autoplay?: boolean;
    muted?: boolean;
    enableUi?: boolean;
    isWithinIFrame?: boolean;
    volume?: IntRange<0, 101>;
    detachable?: boolean;
    thumbnail?: string;
    watermark?: WatermarkOptions;
    defaultErrorMessage?: string;
    defaultOfflineMessage?: string;
    defaultOfflineTimeoutDuration?: number;
    defaultTimeUpdateDuration?: number;
    styles?: StyleOptions;
    onReady?: () => void;
    onError?: (error: string | number | MediaError) => void;
    onPlay?: () => void;
    onPause?: () => void;
    onStreamOffline?: () => void;
    onTimeUpdate?: (metadata: PlayerMetadata) => void;
};
/** Player metadata type containing livestream information */
export type PlayerMetadata = {
    bandwidth?: number;
    bufferLength?: number;
    currentTime?: number;
    duration?: number;
    mediaInfo?: {
        mediaBytesTransferred?: number;
        mediaRequests?: number;
        mediaRequestsAborted?: number;
        mediaRequestsErrored?: number;
        mediaRequestsTimedout?: number;
        mediaSecondsLoaded?: number;
        mediaSequence?: number;
    };
    playerDimensions?: {
        height?: number;
        width?: number;
    };
    timestamp?: number;
    videoPlaybackQuality?: {
        corruptedVideoFrames?: number;
        droppedVideoFrames?: number;
        totalVideoFrames?: number;
        framesPerSecond: number;
    };
};
