import { ExtendedPlayer, StringKeyValuePair, StyleOptions } from "../types";
/**
 * Checks if the provided URL for the player is valid
 * @param url URL to be validated
 * @returns {boolean} Validity of the URL
 */
export declare const isValidBayesWebPlayerURL: (url: string) => boolean;
/**
 * Map and flatten style object
 * @param {StyleOptions} styles Style object to be flattened
 * @returns {StringKeyValuePair} Flattened style object
 */
export declare const flattenStyleObject: (styles: StyleOptions) => StringKeyValuePair;
/**
 * Get player low level information
 * @param {ExtendedPlayer} Video.JS player object
 * @returns {PlayerMetadata} Low level metadata object
 */
export declare const getLowLevelInformation: (player: ExtendedPlayer) => {
    bufferLength: number;
    currentTime: any;
    duration: any;
    bandwidth: any;
    timestamp: any;
    playerDimensions: any;
    mediaInfo: {
        mediaSequence: any;
        mediaSecondsLoaded: any;
        mediaRequests: any;
        mediaRequestsAborted: any;
        mediaRequestsErrored: any;
        mediaRequestsTimedout: any;
        mediaBytesTransferred: any;
    };
    videoPlaybackQuality: {
        totalVideoFrames: any;
        corruptedVideoFrames: any;
        droppedVideoFrames: any;
        framesPerSecond: number;
    };
} | {
    bufferLength?: undefined;
    currentTime?: undefined;
    duration?: undefined;
    bandwidth?: undefined;
    timestamp?: undefined;
    playerDimensions?: undefined;
    mediaInfo?: undefined;
    videoPlaybackQuality?: undefined;
};
